@@ -1137,7 +1137,8 @@ class Tensor(torch.Tensor):
             ret = Tensor.__torch_function_convert_collect__(ret, collection, cls)
 
             for r in collection:
-                dim1, dim2 = args[1:]
+                dim1 = kwargs.get('dim0', args[1])
+                dim2 = kwargs.get('dim1', args[2])
                 a, b = r._special
                 if a == dim1: a = dim2
                 if a == dim2: a = dim1
@@ -1197,7 +1198,6 @@ class Tensor(torch.Tensor):
         "FOR: cummin cummax cumsum cumprod sum prod min max mean argmin argmax squeeze squeeze_"
         func_name = str(func).split(' of ')[0].split()[-1].strip("'")
 
-
         with torch._C.DisableTorchFunction():
             ret = super().__torch_function__(func, types, args, kwargs)
             if isinstance(ret, type(NotImplemented)):
@@ -1206,7 +1206,7 @@ class Tensor(torch.Tensor):
             ret = Tensor.__torch_function_convert_collect__(ret, collection, cls)
 
             if len(args) > 1:
-                dims = args[1:]
+                dims = kwargs.get('dim', args[1:])
                 if len(dims) == 1 and isinstance(dims[0], (list, tuple)): dims = dims[0]
                 if func_name.startswith('squeeze') and len(dims) == 0:
                     dims = tuple(i for i, x in enumerate(self.ishape) if x == 1)
@@ -1217,7 +1217,7 @@ class Tensor(torch.Tensor):
     @classmethod
     def __torch_function_expanding_func__(cls, func, types, args=(), kwargs=None):
         "FOR: unsqueeze unsqueeze_"
-        dims = args[1:]
+        dims = kwargs.get('dim', args[1:])
         if len(dims) == 1 and isinstance(dims[0], (list, tuple)): dims = dims[0]
 
         with torch._C.DisableTorchFunction():
@@ -1240,7 +1240,9 @@ class Tensor(torch.Tensor):
     @classmethod
     def __torch_function_flatten_func__(cls, func, types, args=(), kwargs=None):
         "FOR: flatten flatten_"
-        dims = args[1:]
+        dims = kwargs.get('dim', args[1:])
+        if isinstance(dims, tuple) and len(dims) <= 0:
+            dims = kwargs.get('start_dim', 0), kwargs.get('end_dim', -1)
 
         with torch._C.DisableTorchFunction():
             ret = super().__torch_function__(func, types, args, kwargs)
